Description: civ.club; Общение и соревнования игроков в Civilization V на русском языке; Цивилизация 5 - моды, юниты, карты; wiki-справочник по игре; турниры, игры онлайн
Keywords: civ.club,игра,Цивилизация,game,Civilization,civ5,Colonization,Колонизация,мод,моды,цива,сетевая,стратегические,походовая,цивилопедия,ladder,PBEM,2K games,firaxis,civ

- Регистрация
- Помощь
- Запомнить?

1. Добро пожаловать, коллега! Если зарегистрировались до 5 ноября 2010, то попробуйте зайти со старыми логином и паролем. Если не получится, то запросите пароль через форму восстановления пароля. Если Вы впервые начинаете работать с сайтовым движком vbulletin, то полистайте FAQ. Перед созданием сообщения следует зарегистрироваться.

# civ.club

Добро пожаловать на civ.club.

1. ## Добро пожаловать! Тем / Сообщений Новое

   1. ## Цивилизаторы всех стран, объединяйтесь!

      Заочные знакомства и встречи в реале - добро пожаловать всем форумам, всем кланам!
      Посольство циврукома | CFR Awards | Встречи в реале

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 350
      - Сообщений: 15,722

      #### Новое:

      Москва. 29 сентября....

      от
      AFro
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      03.10.2015, 12:03

   2. ## Сайт и форум

      Вопросы и предложения по ресурсам наш-фанатиков
      Инструкция по эксплуатации форума | Рассылка

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 327
      - Сообщений: 6,873

      #### Новое:

      Модики

      от
      Ostap352
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      26.11.2015, 22:13

   3. ## Своя игра

      Разработка новой глобальной стратегии
      CardWars | Твоя Цивилизация | Прототипы и готовые игры | Алгоритмы и концепции

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 192
      - Сообщений: 8,485

      #### Новое:

      АЛЬМАНАХ ЦИВИЛИЗАЦИИ Егора...

      от
      Пастух
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      02.12.2015, 05:14

2. ## Civilization: Beyond Earth Тем / Сообщений Новое

   1. ## Civilization: Beyond Earth - ПОЕХАЛИ!

      Горячие сведения об игре

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 13
      - Сообщений: 380

      #### Новое:

      Вопросы по игре)

      от
      Шакал ужастный
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      02.12.2015, 08:09

3. ## Civilization V Тем / Сообщений Новое

   1. ## Civilization 5 - ПОЕХАЛИ!

      Горячие сведения об игре
      Цивилизованный учебник истории

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 234
      - Сообщений: 21,119

      #### Новое:

      Здесь дружно начинаем ругать...

      от
      Comrade_Oleg
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      27.11.2015, 15:47

   2. ## Civ5 - Игровые вопросы

      Любые вопросы и общее обсуждение

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 218
      - Сообщений: 4,980

      #### Новое:

      Открыть всю карту. Возможно?

      от
      pioner
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      02.12.2015, 13:13

   3. ## Civilization 5 - Стратегия игры

      Игровые вопросы | Стратегия игры по LAN/Steam

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 89
      - Сообщений: 3,318

      #### Новое:

      Ваша армия в разные периоды.

      от
      Шакал ужастный
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      03.12.2015, 16:53

   4. ## Civilization 5 - Технические вопросы

      Анализатор сейвов | Купил диск - но качает со STEAM

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 235
      - Сообщений: 3,188

      #### Новое:

      Не отображается некоторая...

      от
      mrlikelot
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      26.11.2015, 17:53

   5. ## Civ 5 - Технические вопросы сетевой игры

      Игра через интернет - нет ни одного сервера

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 98
      - Сообщений: 957

      #### Новое:

      Вылеты при мультиплеере в...

      от
      Гость
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Домашняя страница
      - Просмотр статей

      26.11.2015, 22:57

   6. ## Модная Цивилизация

      Всё о модах и моддинге в Civilization V
      Моды | Карты и сценарии

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 234
      - Сообщений: 4,151

      #### Новое:

      REALISM MOD

      от
      infereni
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      04.12.2015, 00:23

4. ## Действующие Турниры и Общие Игры Тем / Сообщений Новое

   1. ## Свободные игры свободных людей

      Любые классы игр без нашей регламентации - поиск партнёров, вызовы на бой,
      заявки на участие, предложение сетевого host/join

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 100
      - Сообщений: 3,421

      #### Новое:

      В испанский ПитБосс нужна...

      от
      BuDDaH
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      02.12.2015, 10:54

   2. ## Сетевые игры

      Игры в мультиплеер в различных его проявлениях: интернет-, LAN-, хотсит-игры (PBEM проводится в соседнем разделе). Поиск соперников для онлайн-игры, подготовка и проведение сетевых турниров, разработка их правил, обсуждение текущих и сыгранных сетевых игр.
      Сетевые турниры Civ5 | Сетевые турниры Civ4

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 297
      - Сообщений: 24,632

      #### Новое:

      Игра по интернету в мой мод

      от
      Не могу придумать никнейм
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      29.11.2015, 15:07

   3. ## Гран-При

      Старейший турнир в русскоязычном civ-сообществе. Игры с переигровками сейва (класс "reload") - подготовка и проведение турниров, разработка и обсуждение правил Гран-При.

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 126
      - Сообщений: 29,784

      #### Новое:

      Гран-При "Цив! Труд!...

      от
      TPP
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      19.06.2015, 14:19

   4. ## Нон-Релоуд

      Игры без перезагрузки сейва: подготовка, проведение и обсуждение турниров, обсуждение и разработка правил Нон-Релоуда.

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 117
      - Сообщений: 13,295

      #### Новое:

      Обсуждение нового НР турнира

      от
      Я люблю CFR
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      23.01.2015, 11:36

   5. ## Сосисочный Цех: Общие игры

      В этом разделе проводятся "сосиски": общие игры с подробным описанием похождений. Новички найдут здесь наглядное пособие по игре, а ветераны смогут развлечься.
      Морозилка | Завершенные игры | Разнобой

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 80
      - Сообщений: 14,595

      #### Новое:

      Общая игра-сосиска для мода...

      от
      Ostap352
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      20.07.2015, 08:29

   6. ## Почтовые игры

      Игры по e-mail (класс "Play By E-Mail"): поиск соперников, проведение почтовых турниров, обсуждение действующих ПБЕМ-игр.
      Хочу сыграть с кем-нить по мылу

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 227
      - Сообщений: 21,608

      #### Новое:

      Civilization V 152 "Лебедь,...

      от
      BlackSun_rus
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      03.12.2015, 20:44

   7. ## Игры GOTM на civfanatics.com

      Из этого раздела русскоязычные игроки отправляются на ежемесячное покорение их-фанатиков. Присоединяйтесь и принимайте участие в играх Game Of The Month вместе с нами!

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 178
      - Сообщений: 8,783

      #### Новое:

      Civ3 СОТМ 46

      от
      supersova
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      06.09.2015, 10:20

   8. ## Demogames

      Игры в демократию на наш-фанатиках

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 541
      - Сообщений: 52,553

      #### Новое:

      Pitboss ISDG/MTDG III....

      от
      Я люблю CFR
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      23.01.2015, 11:38

   9. ## Другие классы игр и Идеи для новых игр

      Подготовка иных классов игр ("блиц", "раргеймы"), обсуждение правил их проведения, архив уже завершённых игр. Здесь же обсуждаются идеи новых игрищ и соревнований.

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 44
      - Сообщений: 3,120

      #### Новое:

      Stream видео игры, чат и...

      от
      Я люблю CFR
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      23.01.2015, 11:38

   10. ## Правила игры

       Обсуждение общих для всех турниров правил игры, описание запрещённых и разрешённых багов и приёмов

       #### Опции форума:

       - RSS лента этого раздела

       #### Статистика раздела:

       - Тем: 19
       - Сообщений: 777

       #### Новое:

       Заказ нужного числа автосейвов

       от
       Я люблю CFR
       - Просмотр профиля
       - Сообщения форума
       - Записи в дневнике
       - Просмотр статей

       23.01.2015, 11:38

   11. ## Рейтинг участников турниров

       Ведение рейтингов, разработка новых, Зал Славы, Текущий и абсолютный рейтинг, пьедестал, награды, пресс-релизы.

       #### Опции форума:

       - RSS лента этого раздела

       #### Статистика раздела:

       - Тем: 18
       - Сообщений: 1,250

       #### Новое:

       Обсуждение: рейтинг сетевиков

       от
       Я люблю CFR
       - Просмотр профиля
       - Сообщения форума
       - Записи в дневнике
       - Просмотр статей

       23.01.2015, 11:39

5. ## Civilization IV Тем / Сообщений Новое

   1. ## Цивилизация 4 - ПОЕХАЛИ!

      Горячие сведения об игре
      Beyond the Sword: Patch 3.19

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 222
      - Сообщений: 10,093

      #### Новое:

      За какую из цивилизаций BtS...

      от
      Хитрец
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      08.09.2015, 13:03

   2. ## Русификация Civilization IV

      здесь игру CivIV, аддоны Warlords и Beyond the Sword, а также моды к ним обучают языкам.
      Русификация Civilization4: Beyond the Sword v. 3.19

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 136
      - Сообщений: 4,948

      #### Новое:

      Русификация Civ IV в Steam

      от
      Mirgnezi
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      26.11.2015, 21:49

   3. ## Civ4 - Игровые вопросы

      Любые вопросы и общее обсуждение

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 667
      - Сообщений: 11,458

      #### Новое:

      Снос городов

      от
      Шакал ужастный
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      03.12.2015, 11:50

   4. ## Civ4 - Стратегия игры

      Статьи и материалы, посвящённые научному подходу к игре

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 102
      - Сообщений: 3,285

      #### Новое:

      Высший пилотаж: Medieval

      от
      Хитрец
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      23.11.2015, 19:58

   5. ## Civ4 - Технические вопросы

      Всё, что нужно для долгой и счастливой игры в Civilization 4

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 582
      - Сообщений: 5,687

      #### Новое:

      Нетбук Acer One на 1024*600...

      от
      Хитрец
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      11.10.2015, 09:47

   6. ## Civ4 - Технические вопросы сетевой игры

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 112
      - Сообщений: 1,132

      #### Новое:

      Клон Gamespy для civ4

      от
      Ostap352
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      03.12.2015, 21:24

   7. ## Civ4 - Модная Цивилизация

      Всё о модах и моддинге в Civ4
      Официальные моды | Моды и сценарии | Компоненты и утилиты

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 852
      - Сообщений: 34,111

      #### Новое:

      Пожелания по развитию мода...

      от
      romabb
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      03.12.2015, 11:34

6. ## Бильярдная цивилизаторов - разговоры обо всём Тем / Сообщений Новое

   1. ## Поздравьте меня

      ...каждый может похвалить и похвалиться

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 435
      - Сообщений: 13,608

      #### Новое:

      AFro

      от
      pioner
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      27.11.2015, 12:28

   2. ## Разговоры обо всём, кроме Цивилизации

      О реальной жизни - той, что без save/load
      Доска объявлений | Английский клуб | Юмор

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 1,038
      - Сообщений: 81,980

      #### Новое:

      Английский клуб, том 2

      от
      Snake_B
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Домашняя страница
      - Просмотр статей

      04.12.2015, 02:05

   3. ## История

      Лучшее, что дает нам история, - это возбуждаемый ею энтузиазм (Гёте)
      Исторические загадки

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 48
      - Сообщений: 4,662

      #### Новое:

      История Украины

      от
      Saprikin
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      26.11.2015, 10:53

7. ## Civilization III Тем / Сообщений Новое

   1. ## Civ3 - Игровые вопросы

      Любые вопросы и общее обсуждение
      Civ3 - Стратегия игры

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 315
      - Сообщений: 5,123

      #### Новое:

      Создаёте ли вы в начале игры...

      от
      Rag
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      03.12.2015, 22:09

   2. ## Civ3 - Технические вопросы

      Русификация Civilization 3

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 210
      - Сообщений: 2,189

      #### Новое:

      Цивилизация 3 Эволюция

      от
      Роман 1902
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      29.09.2015, 11:47

   3. ## Civ3 - Сетевая игра

      Обсуждение тактик, стратегий, приёмов и финтов, применяемых в игре с людьми.

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 39
      - Сообщений: 398

      #### Новое:

      Количество игроков по сети

      от
      Fabrizio
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      04.04.2015, 09:46

   4. ## Civ3 - Модостроение

      Обсуждение модов Civ3 и вопросов их разработки
      Civ3 - Моды и сценарии

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 157
      - Сообщений: 2,917

      #### Новое:

      Сборный графический пак +...

      от
      KonstantinRed
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      22.10.2015, 21:46

8. ## Civilization Colonization - Колонизация Тем / Сообщений Новое

   1. ## Колонизация - ПОЕХАЛИ!

      Горячие сведения об игре

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 81
      - Сообщений: 1,445

      #### Новое:

      Русификация Civilization IV:...

      от
      Я люблю CFR
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      23.01.2015, 11:45

   2. ## Модная Колонизация

      Все о модах и моддинге в Civ4:Colonization

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 49
      - Сообщений: 1,446

      #### Новое:

      "1492: Global Colonization....

      от
      Bonpoc
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      11.06.2015, 06:41

9. ## Civilization Revolution Тем / Сообщений Новое

   приставочная версия игры

   1. ## Новости о Civilization Revolution

      #### Опции форума:

      - RSS лента этого раздела

      #### Статистика раздела:

      - Тем: 6
      - Сообщений: 143

      #### Новое:

      Вопросы по игре(новенький)

      от
      AlonZo
      - Просмотр профиля
      - Сообщения форума
      - Записи в дневнике
      - Просмотр статей

      14.09.2015, 12:33

10. ## CivWorld - первая Civilization он-лайн от Сида Мейера Тем / Сообщений Новое

    1. ## CivWorld - общее обсуждение

       Обсуждение игры CivWorld и общих вопросов, связанных с ней

       #### Опции форума:

       - RSS лента этого раздела

       #### Статистика раздела:

       - Тем: 10
       - Сообщений: 74

       #### Новое:

       программулька помощь в...

       от
       vladyn
       - Просмотр профиля
       - Сообщения форума
       - Записи в дневнике
       - Просмотр статей

       19.08.2012, 01:04

11. ## Истоки Цивилизации Тем / Сообщений Новое

    Civilization I & II, Alpha Centauri, e-civ, Call to Power 1 & 2, FreeCiv

    1. ## Общее обсуждение

       #### Опции форума:

       - RSS лента этого раздела

       #### Статистика раздела:

       - Тем: 12
       - Сообщений: 817

       #### Новое:

       Цивилизация 2

       от
       Comrade_Oleg
       - Просмотр профиля
       - Сообщения форума
       - Записи в дневнике
       - Просмотр статей

       28.09.2015, 14:05

12. ## Другие игры Тем / Сообщений Новое

    Здесь цивилизаторы узнают о существовании других игр

    1. ## Стратегии

       Стратегические игры
       Total War | Europa Universalis | Герои (HoM&M) | Sid Meier's Pirates!

       #### Опции форума:

       - RSS лента этого раздела

       #### Статистика раздела:

       - Тем: 208
       - Сообщений: 1,954

       #### Новое:

       Crusader Kings 2

       от
       Шакал Ужасный
       - Просмотр профиля
       - Сообщения форума
       - Записи в дневнике
       - Просмотр статей

       28.11.2015, 07:36

    2. ## Ролевые игры

       RPG, тактические RPG

       #### Опции форума:

       - RSS лента этого раздела

       #### Статистика раздела:

       - Тем: 13
       - Сообщений: 452

       #### Новое:

       The Elder Scrolls V: Skyrim

       от
       Шакал ужастный
       - Просмотр профиля
       - Сообщения форума
       - Записи в дневнике
       - Просмотр статей

       04.12.2015, 02:35

    3. ## Action и 3D-шутеры

       Бродилки-стрелялки

       #### Опции форума:

       - RSS лента этого раздела

       #### Статистика раздела:

       - Тем: 3
       - Сообщений: 7

       #### Новое:

       Star Wars The Force Unleashed...

       от
       Я люблю CFR
       - Просмотр профиля
       - Сообщения форума
       - Записи в дневнике
       - Просмотр статей

       23.01.2015, 11:48

    4. ## Online игры

       #### Опции форума:

       - RSS лента этого раздела

       #### Статистика раздела:

       - Тем: 36
       - Сообщений: 1,362

       #### Новое:

       Онлайн стратегия - Империя...

       от
       vitaszanoza
       - Просмотр профиля
       - Сообщения форума
       - Записи в дневнике
       - Просмотр статей

       01.12.2015, 15:34

    5. ## Другие игры

       Игры не вошедшие в другие категории

       #### Опции форума:

       - RSS лента этого раздела

       #### Статистика раздела:

       - Тем: 110
       - Сообщений: 2,316

       #### Новое:

       Call of Duty Black Ops 3

       от
       Хитрец
       - Просмотр профиля
       - Сообщения форума
       - Записи в дневнике
       - Просмотр статей

       15.08.2015, 08:25

Все разделы прочитаны | Руководство сайта

## Кто на сайте

### Сегодня день рождения у

1. mihaylo (42),
2. dmikos (30),
3. energy (30),
4. Эйрик (19)

### Статистика civ.club

Тем
  11,728
Сообщений
  494,132
Пользователи
  55,641
Активные участники
  3,448

Приветствуем нового пользователя, maxxw

Дневники
  68
Записи
  961
Последние сутки
  1

Самая новая запись, И - Индустриализ от Шакал ужастный

### Список иконок

  Непрочитанные сообщения
  Нет непрочитанных сообщений
  Закрыто для сообщений
  Категория
  Ссылка